@@ -4,5 +4,5 @@ from AnnotatedTree.Layer.TargetLanguageWordLayer import TargetLanguageWordLayer
 class PersianWordLayer(TargetLanguageWordLayer):
 
     def __init__(self, layerValue: str):
-        super().__init__(layerValue)
+        super().TargetLanguageWordLayer(layerValue)
         self.layerName = "persian"
